function [regnum,frdate,max_alphah] = app_max(y,x,ndn,m,T_star,E,k)

% Applies the MAX procedure.
%
%   INPUTS:
%       y - T by 1 regressand
%       x - T by 1 regressor
%       ndn - T by 1 vector of dates
%       m - subsample size 
%       T_star - end of training period
%       E - end of monitoring
%       k - separation
%
%   OUTPUTS:
%       regnum - number of PRs (<= 3)
%       frdate - first PR date
%       max_alphah - empirical FPR associated with frdate

warning('off');
formatOut = 'mm/yy';
regnum = 0;
frdate = -99;
max_alphah = -99;
lx = lag1(x);
tm_vec = zeros(E,1);

e = m+1;
while e <= E
    y_sub = y(e-m+1:e,1);
    lx_sub = lx(e-m+1:e,1);
    tm_vec(e,1) = t_sub_proc(y_sub-mean(y_sub),lx_sub-mean(lx_sub));
    e = e+1;
end

alphah = zeros(E,1);
alphah(1:T_star+m-1,1) = NaN([T_star+m-1,1]);
E_max = E;
    
Ei = T_star+m;
while Ei <= E_max
    alphah(Ei,1) = (Ei-T_star-m+1)/(Ei-2*m+1-k);
    Ei = Ei+1;
end

trainvec = tm_vec(m+1:T_star-k,1);
monvec = tm_vec(T_star+m:E,1);
maxtrainvec = max(trainvec);
monrej = monvec > maxtrainvec;
[maxmaxmon,dum1m,dum2m] = max_proc(monrej);

if maxmaxmon > 0 
    ij = 1;
    while maxmaxmon > 0
        regnum = regnum+1;  
        rsdate(ij,1) = T_star+m+dum1m-1;
        redate(ij,1) = T_star+m+dum2m-1;
        monrej(dum1m:dum2m,1) = zeros(dum2m-dum1m+1,1);
        ij = ij+1;
        [maxmaxmon,dum1m,dum2m] = max_proc(monrej);
    end

    if regnum > 3
        regnum = 3;
    end
    
    rsdate = sort(rsdate);
    redate = sort(redate);    
    frdate = datestr(ndn(rsdate(1,1)),formatOut);
    max_alphah = alphah(rsdate(1,1));
end

frdate = miss(frdate,-99);
max_alphah = miss(max_alphah,-99);
end

